@@ -1,23 +1,22 @@
 <?php
 
-# PHP libraries
+// PHP libraries
 $dolibarr_lib_ADODB_PATH='/usr/share/php/adodb';
-$dolibarr_lib_FPDF_PATH='';
-$dolibarr_lib_FPDI_PATH='/usr/share/php/fpdi';
 $dolibarr_lib_GEOIP_PATH='';
 $dolibarr_lib_NUSOAP_PATH='/usr/share/php/nusoap';
 $dolibarr_lib_ODTPHP_PATH='';
-$dolibarr_lib_ODTPHP_PATHTOPCLZIP='/usr/share/php/libphp-pclzip';
+$dolibarr_lib_ODTPHP_PATHTOPCLZIP='/usr/share/php';
 $dolibarr_lib_PHPEXCEL_PATH='disabled';
 $dolibarr_lib_TCPDF_PATH='/usr/share/php/tcpdf';
 
-# Javascript libraries
-$dolibarr_js_CKEDITOR='disabled';
+// Javascript libraries
+// External javascript libraries are store into /usr/share/ in debian
+$dolibarr_js_CKEDITOR='/javascript/ckeditor';
 $dolibarr_js_JQUERY='/javascript/jquery';
 $dolibarr_js_JQUERY_UI='/javascript/jquery-ui';
 $dolibarr_js_JQUERY_FLOT='/javascript/flot';
 
-# Fonts
+// Fonts
 if (file_exists('/usr/share/fonts/truetype/dejavu/DejaVuSans-Bold.ttf')) {
 	$dolibarr_font_DOL_DEFAULT_TTF_BOLD='/usr/share/fonts/truetype/dejavu/DejaVuSans-Bold.ttf';
 } else if (file_exists('/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans-Bold.ttf')) {
@@ -28,4 +27,4 @@ if (file_exists('/usr/share/fonts/truetype/dejavu/DejaVuSans.ttf')) {
 } else if (file_exists('/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf')) {
 	$dolibarr_font_DOL_DEFAULT_TTF='/usr/share/fonts/truetype/ttf-dejavu/DejaVuSans.ttf';
 }
-?>
+
